/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 *
 * (C) Copyright IBM Corp. 2002, 2006 All Rights Reserved.
 * (C) Copyright Webify Solutions, Inc. 2002, 2006 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.fabric.banking.util;

import payment.vendor.vendor.payment.interface_.VendorPayment;

import java.util.List;

import com.ibm.websphere.fabric.da.context.InContextServiceInvoker;
import com.ibm.websphere.sca.Service;
import com.ibm.websphere.sca.ServiceManager;
import com.ibm.websphere.sca.Ticket;

import commonj.sdo.DataObject;

/**
 * Takes the context properties from the request and uses the ContextPropagator to
 * inject the context properties for the service.
 * 
 * @author pmangesh
 *
 */
public class ContextInjectorClientImpl {

    public ContextInjectorClientImpl() {
        super();
    }

    public DataObject makePayment(DataObject request, DataObject contextHeader) {
        BankingSubmissionContext contextWrapper = new BankingSubmissionContext(request, contextHeader);
        return (DataObject) contextWrapper.invokeInContext();
    }

    /**
     * Locates the partner service.
     */
    //CHECKSTYLE:OFF    
    public VendorPayment locateService_ActualProcess() {
        return (VendorPayment) ServiceManager.INSTANCE
                .locateService("VendorPaymentPartner");
    }
    
    public void onMakePaymentResponse(Ticket __ticket, DataObject returnValue, Exception exception) {
        // not implemented
    }
    //CHECKSTYLE:ON
    /**
     * 
     * @author pmangesh
     *
     */
    private class BankingSubmissionContext extends InContextServiceInvoker {

        public BankingSubmissionContext(DataObject request, DataObject contextHeader) {
            super(request, contextHeader);
            List list = contextHeader.getList("property");

            for (int i = 0; i < list.size(); ++i) {
                DataObject pair = (DataObject) list.get(i);
                String key = pair.getString("name");
                String val = pair.getString(0);
                setSelectionProperty(key, val);
            }
        }

        public Object invoke() {
            
            Service svc = (Service) locateService_ActualProcess(); 
            return svc.invoke("makePayment", getBody());
        }
    }
}