package com.ibm.websphere.fabric.banking.util;


import java.io.IOException;
import java.io.InputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import com.ibm.websphere.fabric.da.util.SdoXPathUtil;
import com.ibm.websphere.fabric.industry.support.util.IndustrySupportUtil;
import com.ibm.websphere.fabric.industry.support.util.SDOTransformationUtils;
import commonj.sdo.DataObject;


public class VendorPaymentDataAssignmentHelper {
	
	 /**
     * Required details are set in the custDetailsResponse with the values from acordResponse.
     *
     * @param pain00100102Request
     * @param vendorPaymentUIRequest
     */
    public DataObject assignInputToPain00100102Request(DataObject pain00100102Request, DataObject vendorPaymentUIRequest) {
    	
		InputStream is = getClass().getResourceAsStream("pain00100102-req.xml");
		
		try {
			pain00100102Request = SDOTransformationUtils.createDataObject(is);
		} catch(IOException e) {
			System.out.println("IOException: " + e);
		}
		
		//Setting the pain.001.001.02 document with the input UI
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Cdtr")
				.getValue()).setString("Nm", vendorPaymentUIRequest.getString("VendorName"));
		
		List addrList = new ArrayList();
		addrList.add(vendorPaymentUIRequest.getString("Address"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Cdtr/PstlAdr")
				.getValue()).setList("AdrLine", addrList);
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Cdtr/PstlAdr")
				.getValue()).setString("TwnNm", vendorPaymentUIRequest.getString("City"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Cdtr/PstlAdr")
				.getValue()).setString("Ctry", vendorPaymentUIRequest.getString("Country"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Cdtr/PstlAdr")
				.getValue()).setString("PstCd", vendorPaymentUIRequest.getString("State") + vendorPaymentUIRequest.getString("Zip"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/CdtrAcct/Id/PrtryAcct")
				.getValue()).setString("Id", vendorPaymentUIRequest.getString("VendorAccNum"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/CdtrAgt/FinInstnId")
				.getValue()).setString("BIC", vendorPaymentUIRequest.getString("VendorRoutingNum"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/DbtrAcct/Id/PrtryAcct")
				.getValue()).setString("Id", vendorPaymentUIRequest.getString("WithdrawAccNum"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/DbtrAgt/FinInstnId")
				.getValue()).setString("BIC", vendorPaymentUIRequest.getString("WithdrawRoutingNum"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Amt/InstdAmt")
				.getValue()).set("value", vendorPaymentUIRequest.getString("PaymentAmount"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//GrpHdr")
				.getValue()).setDouble("CtrlSum", Double.parseDouble(vendorPaymentUIRequest.getString("PaymentAmount")));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/CdtTrfTxInf[1]/Amt/InstdAmt")
				.getValue()).setString("Ccy", vendorPaymentUIRequest.getString("Currancy"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]")
				.getValue()).setDate("ReqdExctnDt", vendorPaymentUIRequest.getDate("PaymentDate"));
		
		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//PmtInf[1]/PmtTpInf")
		.getValue()).setString("ClrChanl", vendorPaymentUIRequest.getString("PaymentType"));
		
		// Assigning the Creation Date time:
		SimpleDateFormat creationDateTimeFormat = new SimpleDateFormat(
				"yyyy-MM-dd'T'HH:mm:ss");
		
		Calendar cal = Calendar.getInstance();
		int offset = (cal.get(Calendar.ZONE_OFFSET) + cal
				.get(Calendar.DST_OFFSET));
		long seconds = cal.getTimeInMillis();
		cal.setTimeInMillis(seconds - offset);
		Date date = cal.getTime();

		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request, "//GrpHdr")
				.getValue())
				.set("CreDtTm", creationDateTimeFormat.format(date));
		

		// Creating and setting Dynamic transaction ID:
		SimpleDateFormat txnIdDateTimeFormat = new SimpleDateFormat(
		"yyyyMMdd'T'HHmmss");

		String txsID = txnIdDateTimeFormat.format(date).toString();
		txsID =  "TXN-" + txsID; 

		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request,
				"//PmtInf[1]/CdtTrfTxInf[1]/PmtId").getValue()).set("InstrId",
				txsID);

		((DataObject) SdoXPathUtil.getViaXpath(pain00100102Request,
				"//PmtInf[1]/CdtTrfTxInf[1]/PmtId").getValue()).setString(
				"EndToEndId", txsID);

		return pain00100102Request;
    	
    }
    
    public static DataObject assignPain00200102OutputToUIOutput (DataObject pain00200101Response, DataObject vendorPaymentResponse) {
    	
    	vendorPaymentResponse = IndustrySupportUtil.createDO("http://www.ibm.com/xmlns/prod/websphere/fabric/2009/12/banking/payments/schema/VendorPaymentUIResponse",
    								"VendorPaymentUIResponse");
    	
    	if (SdoXPathUtil.getViaXpath(pain00200101Response, "//TxInfAndSts[1]/OrgnlInstrId") != null) {
    		String txsId = (String) SdoXPathUtil.getViaXpath(pain00200101Response, "//TxInfAndSts[1]/OrgnlInstrId").getValue();
    		vendorPaymentResponse.setString("TxsID", txsId);
   		
    	}
    	
    	if (SdoXPathUtil.getViaXpath(pain00200101Response, "//TxInfAndSts[1]/TxSts") != null) {
    		String txsStatus = (String) SdoXPathUtil.getViaXpath(pain00200101Response, "//TxInfAndSts[1]/TxSts").getValue(); 
    		vendorPaymentResponse.setString("TxsStatus", txsStatus);
    	}
    	
    	return vendorPaymentResponse;
    	
    }
    
	public static DataObject getContext() {

    	DataObject context = IndustrySupportUtil.createDO("http://www.webifysolutions.com/2006/01/prism-context","ContextTypeExt");
		DataObject contextProperty_01 = IndustrySupportUtil.createDO("http://www.webifysolutions.com/2006/01/prism-context","ContextPropertyType");
		DataObject contextProperty_02 = IndustrySupportUtil.createDO("http://www.webifysolutions.com/2006/01/prism-context","ContextPropertyType");
		DataObject contextProperty_03 = IndustrySupportUtil.createDO("http://www.webifysolutions.com/2006/01/prism-context","ContextPropertyType");


		//DataObject contextId = IndustrySupportUtil.createDO("http://docs.oasis-open.org/wscaf/2005/10/wsctx","contextIdentifierType");
		//contextId.set("value", "ID:ISL106-1165-1240916946140-0:1");
		//contextProperty_01.setString("name","http://www.webifysolutions.com/2005/10/catalog/governance#Environment");
		//contextProperty_01.setString("value","fc://fabric/governance/default-inst#default");
		contextProperty_01.setString("name","http://www.webifysolutions.com/context/debug");
		contextProperty_01.setString("value","true");
		contextProperty_02.setString("name","http://www.webifysolutions.com/context/interface");
		contextProperty_02.setString("value","http://VendorPayment/VendorPaymentInterface#VendorPayment");
		contextProperty_03.setString("name","http://www.webifysolutions.com/2005/10/catalog/governance#FabricProject");
		contextProperty_03.setString("value","fc://fabric/governance/fabricproject-inst#71e99f5f-d80c-41a9-8956-365752f58d0d");

		List propertyList = new ArrayList() ;
		//propertyList.add(contextProperty_01);
		propertyList.add(contextProperty_01);
		propertyList.add(contextProperty_02);
		propertyList.add(contextProperty_03);


		//context.setDataObject("context-identifier", contextId);
		context.setList("property",propertyList);
		return context;
    }    

}
