/***********************************************
 * Licensed Materials - Property of IBM
 * 
 * 5724-R31, 5655-S30
 * 
 * (C) Copyright IBM Corp. 2009 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 ***********************************************
 */
package com.ibm.websphere.icp.banking.context.extractor;

import java.util.logging.Logger;

import com.ibm.websphere.fabric.da.PendingRequest;
import com.ibm.websphere.fabric.da.context.Context;
import com.ibm.websphere.fabric.da.plugin.ContextExtractor;
import com.ibm.websphere.fabric.da.plugin.UnexpectedContentException;
import com.ibm.websphere.fabric.da.types.TypedValue;
import com.ibm.websphere.icp.banking.util.BankingConstants;
import com.ibm.websphere.icp.banking.util.BankingUtil;
import com.ibm.websphere.sca.ServiceManager;
import commonj.sdo.DataObject;

public class CheckCreditScoreContextExtractorImpl implements ContextExtractor {

	private final Logger logger = Logger.getLogger("CheckCreditScoreContextExtractorImpl");
	
	
	/**
	 * Default constructor.
	 */
	public CheckCreditScoreContextExtractorImpl() {
		super();
	}

	/**
	 * Return a reference to the component service instance for this implementation
	 * class.  This method should be used when passing this service to a partner reference
	 * or if you want to invoke this component service asynchronously.    
	 *
	 * @generated (com.ibm.wbit.java)
	 */
	@SuppressWarnings("unused")
	private ContextExtractor getMyService() {
		return (ContextExtractor) ServiceManager.INSTANCE.locateService("self");
	}

	/* (non-Javadoc)
	 * @see com.ibm.websphere.fabric.da.plugin.ContextExtractor#extractContext(PendingRequest arg0) 
	 */
	public Context extractContext(PendingRequest pendingRequest)
			throws UnexpectedContentException {

		logger.info("in extractContext of CheckCreditScoreContextExtractorImpl");
		Context context = pendingRequest.getContext();
		logger.info("context.:" + context.getSelectionPropertyNames());
	        
        DataObject requestDataObject = (DataObject) pendingRequest.getFirstBodyElement();
         
        String xpath = BankingConstants.CREDIT_RATING_CMDTYPE;
        String cmdType = (String) BankingUtil.getValueFromXPath(requestDataObject, xpath);
        logger.info("Got "+xpath+": " + cmdType);
        
        //for only using data from context remove this.
        if (cmdType == null || (cmdType!=null && cmdType.trim().equals(BankingConstants.EMPTY))) {
        	cmdType = "555";
        }
        logger.info("Transaction Amount:" + cmdType);
        
        TypedValue assersionValue = new TypedValue(cmdType);
        context.setSelectionProperty(BankingConstants.TRANSACTION_AMOUNT_ASSERTION, assersionValue);

        logger.info("Transaction Amount Assertion set to context.");        
                
    	TypedValue governanceFabricProjectValue = new TypedValue(BankingConstants.FABRIC_GOVERNANCE);
		context.setSelectionProperty(BankingConstants.FABRIC_GOVERNANCE_VALUE, governanceFabricProjectValue);
        return context;
	}
}